from Gnumeric import *
import string
import gsf
from os.path import basename, splitext
from time import strftime, localtime, time

def save_sheet_as_po(sheet, output):
	(lang, _) = splitext(basename(output.name()))
		
	for col in range(2, sheet.get_extent().end.col + 1):
		if string.lower(sheet[col, 0].get_value_as_string()) == lang:
			lang_col = col
			break
	else:
		lang_col = col + 1
	header = open(plugin_info.get_dir_name() + '/glossary-po-header').read()
	str = header % {'lang': lang, 'creation_date': strftime('%Y-%m-%d %H:%M%Z', localtime(time()))}
	output.write(len(str), str)
	entries = []
	for row in range(1, sheet.get_extent().end.row + 1):
		term = sheet[0, row].get_value_as_string()
		definition = sheet[1, row].get_value_as_string()
		translation = sheet[lang_col, row].get_value_as_string()
		if term:
			entries.append({'term': term, 'definition': definition, 'translation' : translation})
		elif definition:
			entries[-1]['definition'] = '%s\n%s' % (entries[-1]['definition'], definition)
	for e in entries:
		print(e)
		output.write(len('\n'), '\n')
		for d in string.split(e['definition'], '\n'):
			str = '#. %s\n' % d
			output.write(len(str), str)
		str = 'msgid "%s"\n' % e['term']
		output.write(len(str), str)
		str = 'msgstr "%s"\n' % e['translation']
		output.write(len(str), str)

def po_file_save(wb, output):
	for sheet in wb.sheets():
		if sheet[0, 0].get_value_as_string() == 'Term':
			save_sheet_as_po (sheet, output)
			break
	else:
		raise GnumericError('Could not find Gnome Glossary sheet')



from Gnumeric import *
import string

# Here is a function with variable number of arguments
def func_printf(format, *args):
	'@FUNCTION=PY_PRINTF\n'\
	'@SYNTAX=PY_PRINTF (format,...)\n'\
	'@DESCRIPTION='\
	'\n'\
	'@EXAMPLES=\n'\
	'PY_PRINTF("Test: %.2f",12) equals "Test: 12.00")'\
	'\n'\
	'@SEEALSO='

	try:
		val = format % args
	except TypeError:
		raise GnumericError(GnumericErrorVALUE)
	else:
		return val

# Here is a function with one argument
def func_capwords(str):
	'@FUNCTION=PY_CAPWORDS\n'\
	'@SYNTAX=PY_CAPWORDS (sentence)\n'\
	'@DESCRIPTION='\
	'\n'\
	'@EXAMPLES=\n'\
	'PY_CAPWORDS("Hello world") equals "Hello World")'\
	'\n'\
	'@SEEALSO='

	return string.capwords(str)

# Here is a function which calls a spreadsheet function
def func_bitand(num1, num2):
	'@GNM_FUNC_HELP_NAME@BITAND:bitwise AND of its two arguments.\n'\
	'@GNM_FUNC_HELP_ARG@number1:first value\n'\
	'@GNM_FUNC_HELP_ARG@number2:second value\n'\
	'@GNM_FUNC_HELP_EXAMPLES@=PY_BITAND(12, 6)\n'\
	'@GNM_FUNC_HELP_SEEALSO@BITAND'
	gnm_bitand=functions['bitand']
	return gnm_bitand(num1, num2)

test_functions = {
	# Here we tell Gnumeric that the Python function 'func_printf'
	# provides the spreadsheet function 'py_printf', and that
	# 'py_printf' may be called with any number of arguments [1].
	'py_printf': func_printf,

	# 'func_capwords' provides the spreadsheet function 'py_capwords'.
	# 'py_capwords' should be called with a single argument.
	# This should be a string ('s'), and the argument name is 'sentence'.
	'py_capwords': ('s', 'sentence', func_capwords),

	# 'func_bitand' provides 'bitand', which should be called with two
	# numeric arguments (ff) named 'num1' and 'num2'.
	'py_bitand':   ('ff', 'num1, num2', func_bitand)
}


# [1] Actually, the 'def func_printf' statement says that it requires at least
#     one argument. But there is no way to express that in the syntax used in
#     the 'test_functions' dictionary.
